@@ -40,44 +40,58 @@
 #include "DiskAdaptor.h"
 #include "prefs.h"
 #include "Option.h"
-#include "DownloadContext.h"
+#include "util.h"
+#include "SingletonHolder.h"
+#include "Notifier.h"
 
 namespace aria2 {
 
-BtCheckIntegrityEntry::BtCheckIntegrityEntry(RequestGroup* requestGroup):
-  PieceHashCheckIntegrityEntry(requestGroup, 0) {}
+BtCheckIntegrityEntry::BtCheckIntegrityEntry(RequestGroup* requestGroup)
+    : PieceHashCheckIntegrityEntry(requestGroup, nullptr)
+{
+}
 
 BtCheckIntegrityEntry::~BtCheckIntegrityEntry() {}
 
-void BtCheckIntegrityEntry::onDownloadIncomplete
-(std::vector<Command*>& commands, DownloadEngine* e)
+void BtCheckIntegrityEntry::onDownloadIncomplete(
+    std::vector<std::unique_ptr<Command>>& commands, DownloadEngine* e)
 {
-  const SharedHandle<DiskAdaptor>& diskAdaptor =
-    _requestGroup->getPieceStorage()->getDiskAdaptor();
-  if(diskAdaptor->isReadOnlyEnabled()) {
+  auto& ps = getRequestGroup()->getPieceStorage();
+  ps->onDownloadIncomplete();
+  if (getRequestGroup()->getOption()->getAsBool(PREF_HASH_CHECK_ONLY)) {
+    return;
+  }
+  const auto& diskAdaptor = ps->getDiskAdaptor();
+  if (diskAdaptor->isReadOnlyEnabled()) {
     // Now reopen DiskAdaptor with read only disabled.
     diskAdaptor->closeFile();
     diskAdaptor->disableReadOnly();
     diskAdaptor->openFile();
   }
-  SharedHandle<BtFileAllocationEntry> entry
-    (new BtFileAllocationEntry(_requestGroup));
-  proceedFileAllocation(commands, entry, e);
+  proceedFileAllocation(
+      commands, make_unique<BtFileAllocationEntry>(getRequestGroup()), e);
 }
 
-void BtCheckIntegrityEntry::onDownloadFinished
-(std::vector<Command*>& commands, DownloadEngine* e)
+void BtCheckIntegrityEntry::onDownloadFinished(
+    std::vector<std::unique_ptr<Command>>& commands, DownloadEngine* e)
 {
+  auto group = getRequestGroup();
+  const auto& option = group->getOption();
+  if (option->getAsBool(PREF_BT_ENABLE_HOOK_AFTER_HASH_CHECK)) {
+    util::executeHookByOptName(group, option.get(),
+                               PREF_ON_BT_DOWNLOAD_COMPLETE);
+    SingletonHolder<Notifier>::instance()->notifyDownloadEvent(
+        EVENT_ON_BT_DOWNLOAD_COMPLETE, group);
+  }
   // TODO Currently,when all the checksums
-  // are valid, then aira2 goes to seeding mode. Sometimes it is better
+  // are valid, then aria2 goes to seeding mode. Sometimes it is better
   // to exit rather than doing seeding. So, it would be good to toggle this
   // behavior.
-  if(_requestGroup->getOption()->getAsBool(PREF_BT_HASH_CHECK_SEED)) {
-    SharedHandle<BtFileAllocationEntry> entry
-      (new BtFileAllocationEntry(_requestGroup));
-    proceedFileAllocation(commands, entry, e);
+  if (!option->getAsBool(PREF_HASH_CHECK_ONLY) &&
+      option->getAsBool(PREF_BT_HASH_CHECK_SEED)) {
+    proceedFileAllocation(
+        commands, make_unique<BtFileAllocationEntry>(getRequestGroup()), e);
   }
 }
 
-
 } // namespace aria2
