@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_INTERESTED_MESSAGE_H_
-#define _D_BT_INTERESTED_MESSAGE_H_
+#ifndef D_BT_INTERESTED_MESSAGE_H
+#define D_BT_INTERESTED_MESSAGE_H
 
 #include "ZeroBtMessage.h"
 
@@ -42,30 +42,30 @@ namespace aria2 {
 class PeerStorage;
 class BtInterestedMessage;
 
-typedef SharedHandle<BtInterestedMessage> BtInterestedMessageHandle;
-
 class BtInterestedMessage : public ZeroBtMessage {
 private:
-  SharedHandle<PeerStorage> peerStorage_;
+  PeerStorage* peerStorage_;
+
 public:
   BtInterestedMessage();
+  virtual ~BtInterestedMessage();
 
   static const uint8_t ID = 2;
 
-  static const std::string NAME;
+  static const char NAME[];
 
-  static SharedHandle<BtInterestedMessage> create
-  (const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtInterestedMessage> create(const unsigned char* data,
+                                                     size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual bool sendPredicate() const;
+  virtual bool sendPredicate() const CXX11_OVERRIDE;
 
-  virtual void onSendComplete();
+  virtual std::unique_ptr<ProgressUpdate> getProgressUpdate() CXX11_OVERRIDE;
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(PeerStorage* peerStorage);
 };
 
 } // namespace aria2
 
-#endif // _D_BT_INTERESTED_MESSAGE_H_
+#endif // D_BT_INTERESTED_MESSAGE_H
