@@ -32,14 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_MESSAGE_H_
-#define _D_BT_MESSAGE_H_
+#ifndef D_BT_MESSAGE_H
+#define D_BT_MESSAGE_H
 
 #include "common.h"
 
 #include <string>
 
-#include "SharedHandle.h"
 #include "BtAbortOutstandingRequestEvent.h"
 #include "BtCancelSendingPieceEvent.h"
 #include "BtChokingEvent.h"
@@ -51,13 +50,12 @@ class BtEvent;
 class BtMessage {
 private:
   uint8_t id_;
+
 public:
-  BtMessage(uint8_t id):id_(id) {}
+  BtMessage(uint8_t id) : id_(id) {}
 
   virtual ~BtMessage() {}
 
-  virtual bool isSendingInProgress() = 0;
-
   virtual bool isInvalidate() = 0;
 
   virtual bool isUploading() = 0;
@@ -70,22 +68,19 @@ public:
 
   virtual void validate() = 0;
 
-  virtual void onAbortOutstandingRequestEvent
-  (const BtAbortOutstandingRequestEvent& event) = 0;
+  virtual void onAbortOutstandingRequestEvent(
+      const BtAbortOutstandingRequestEvent& event) = 0;
 
-  virtual void onCancelSendingPieceEvent
-  (const BtCancelSendingPieceEvent& event) = 0;
+  virtual void
+  onCancelSendingPieceEvent(const BtCancelSendingPieceEvent& event) = 0;
 
   virtual void onChokingEvent(const BtChokingEvent& event) = 0;
 
   virtual void onQueued() = 0;
 
   virtual std::string toString() const = 0;
-
 };
 
-typedef SharedHandle<BtMessage> BtMessageHandle;
-
 } // namespace aria2
 
-#endif // _D_BT_MESSAGE_H_
+#endif // D_BT_MESSAGE_H
