@@ -124,7 +124,9 @@ void printSizeProgress(ColorizedStream& o,
     o << sizeFormatter(rg->getCompletedLength()) << "B/"
       << sizeFormatter(rg->getTotalLength()) << "B";
     if (rg->getTotalLength() > 0) {
-      o << "(" << 100 * rg->getCompletedLength() / rg->getTotalLength() << "%)";
+      o << colors::cyan << "("
+        << 100 * rg->getCompletedLength() / rg->getTotalLength() << "%)";
+      o << colors::clear;
     }
   }
 }
@@ -138,11 +140,12 @@ void printProgressCompact(ColorizedStream& o, const DownloadEngine* e,
     NetStat& netstat = e->getRequestGroupMan()->getNetStat();
     int dl = netstat.calculateDownloadSpeed();
     int ul = netstat.calculateUploadSpeed();
-    o << "[DL:" << colors::green << sizeFormatter(dl) << "B" << colors::clear;
+    o << colors::magenta << "[" << colors::clear << "DL:" << colors::green
+      << sizeFormatter(dl) << "B" << colors::clear;
     if (ul) {
       o << " UL:" << colors::cyan << sizeFormatter(ul) << "B" << colors::clear;
     }
-    o << "]";
+    o << colors::magenta << "]" << colors::clear;
   }
 
   const RequestGroupList& groups = e->getRequestGroupMan()->getRequestGroups();
@@ -152,9 +155,10 @@ void printProgressCompact(ColorizedStream& o, const DownloadEngine* e,
        ++i, ++cnt) {
     const std::shared_ptr<RequestGroup>& rg = *i;
     TransferStat stat = rg->calculateStat();
-    o << "[#" << GroupId::toAbbrevHex(rg->getGID()) << " ";
+    o << colors::magenta << "[" << colors::clear << "#"
+      << GroupId::toAbbrevHex(rg->getGID()) << " ";
     printSizeProgress(o, rg, stat, sizeFormatter);
-    o << "]";
+    o << colors::magenta << "]" << colors::clear;
   }
   if (cnt < groups.size()) {
     o << "(+" << groups.size() - cnt << ")";
@@ -172,7 +176,8 @@ void printProgress(ColorizedStream& o, const std::shared_ptr<RequestGroup>& rg,
     eta =
         (rg->getTotalLength() - rg->getCompletedLength()) / stat.downloadSpeed;
   }
-  o << "[#" << GroupId::toAbbrevHex(rg->getGID()) << " ";
+  o << colors::magenta << "[" << colors::clear << "#"
+    << GroupId::toAbbrevHex(rg->getGID()) << " ";
   printSizeProgress(o, rg, stat, sizeFormatter);
   o << " CN:" << rg->getNumConnection();
 #ifdef ENABLE_BITTORRENT
@@ -195,7 +200,7 @@ void printProgress(ColorizedStream& o, const std::shared_ptr<RequestGroup>& rg,
   if (eta > 0) {
     o << " ETA:" << colors::yellow << util::secfmt(eta) << colors::clear;
   }
-  o << "]";
+  o << colors::magenta << "]" << colors::clear;
 }
 } // namespace
 
