@@ -38,8 +38,8 @@
 #include "common.h"
 
 #include <string>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "A2STR.h"
 
 namespace aria2 {
@@ -48,36 +48,28 @@ class DHTNode;
 
 class DHTMessage {
 private:
-  SharedHandle<DHTNode> localNode_;
+  std::shared_ptr<DHTNode> localNode_;
 
-  SharedHandle<DHTNode> remoteNode_;
+  std::shared_ptr<DHTNode> remoteNode_;
 
   std::string transactionID_;
 
   std::string version_;
 
   void generateTransactionID();
+
 public:
-  DHTMessage(const SharedHandle<DHTNode>& localNode,
-             const SharedHandle<DHTNode>& remoteNode,
+  DHTMessage(const std::shared_ptr<DHTNode>& localNode,
+             const std::shared_ptr<DHTNode>& remoteNode,
              const std::string& transactionID = A2STR::NIL);
 
   virtual ~DHTMessage();
 
-  const std::string& getTransactionID() const
-  {
-    return transactionID_;
-  }
+  const std::string& getTransactionID() const { return transactionID_; }
 
-  const SharedHandle<DHTNode>& getLocalNode() const
-  {
-    return localNode_;
-  }
+  const std::shared_ptr<DHTNode>& getLocalNode() const { return localNode_; }
 
-  const SharedHandle<DHTNode>& getRemoteNode() const
-  {
-    return remoteNode_;
-  }
+  const std::shared_ptr<DHTNode>& getRemoteNode() const { return remoteNode_; }
 
   virtual void doReceivedAction() = 0;
 
@@ -91,15 +83,9 @@ public:
 
   virtual std::string toString() const = 0;
 
-  const std::string& getVersion() const
-  {
-    return version_;
-  }
+  const std::string& getVersion() const { return version_; }
 
-  void setVersion(const std::string& version)
-  {
-    version_ = version;
-  }
+  void setVersion(const std::string& version) { version_ = version; }
 
   static const std::string Y;
 
