@@ -39,34 +39,39 @@
 #include "RecoverableException.h"
 #include "message.h"
 #include "Logger.h"
-#include "FileEntry.h"
+#include "LogFactory.h"
 
 namespace aria2 {
 
-DHTTokenUpdateCommand::DHTTokenUpdateCommand(cuid_t cuid,
-                                             DownloadEngine* e,
-                                             time_t interval):
-  TimeBasedCommand(cuid, e, interval) {}
+DHTTokenUpdateCommand::DHTTokenUpdateCommand(cuid_t cuid, DownloadEngine* e,
+                                             std::chrono::seconds interval)
+    : TimeBasedCommand{cuid, e, std::move(interval)}, tokenTracker_{nullptr}
+{
+}
 
 DHTTokenUpdateCommand::~DHTTokenUpdateCommand() {}
 
 void DHTTokenUpdateCommand::preProcess()
 {
-  _exit = _e->_requestGroupMan->downloadFinished() || _e->isHaltRequested();
+  if (getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+      getDownloadEngine()->isHaltRequested()) {
+    enableExit();
+  }
 }
 
 void DHTTokenUpdateCommand::process()
 {
   try {
-    _tokenTracker->updateTokenSecret();
-  } catch(RecoverableException& e) {
-    logger->error(EX_EXCEPTION_CAUGHT, e);
+    tokenTracker_->updateTokenSecret();
+  }
+  catch (RecoverableException& e) {
+    A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
   }
 }
 
-void DHTTokenUpdateCommand::setTokenTracker(const SharedHandle<DHTTokenTracker>& tokenTracker)
+void DHTTokenUpdateCommand::setTokenTracker(DHTTokenTracker* tokenTracker)
 {
-  _tokenTracker = tokenTracker;
+  tokenTracker_ = tokenTracker;
 }
 
 } // namespace aria2
