@@ -40,28 +40,37 @@
 #include "Segment.h"
 #include "SocketCore.h"
 #include "SocketRecvBuffer.h"
+#ifdef HAVE_LIBSSH2
+#include "SftpNegotiationCommand.h"
+#endif // HAVE_LIBSSH2
 
 namespace aria2 {
 
-FtpTunnelResponseCommand::FtpTunnelResponseCommand
-(cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
- RequestGroup* requestGroup,
- const SharedHandle<HttpConnection>& httpConnection,
- DownloadEngine* e,
- const SharedHandle<SocketCore>& s)
-  :AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
-                                httpConnection,e, s)
-{}
+FtpTunnelResponseCommand::FtpTunnelResponseCommand(
+    cuid_t cuid, const std::shared_ptr<Request>& req,
+    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
+    const std::shared_ptr<HttpConnection>& httpConnection, DownloadEngine* e,
+    const std::shared_ptr<SocketCore>& s)
+    : AbstractProxyResponseCommand(cuid, req, fileEntry, requestGroup,
+                                   httpConnection, e, s)
+{
+}
 
 FtpTunnelResponseCommand::~FtpTunnelResponseCommand() {}
 
-Command* FtpTunnelResponseCommand::getNextCommand()
+std::unique_ptr<Command> FtpTunnelResponseCommand::getNextCommand()
 {
-  return new FtpNegotiationCommand(getCuid(), getRequest(), getFileEntry(),
-                                   getRequestGroup(), getDownloadEngine(),
-                                   getSocket());
+#ifdef HAVE_LIBSSH2
+  if (getRequest()->getProtocol() == "sftp") {
+    return make_unique<SftpNegotiationCommand>(
+        getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+        getDownloadEngine(), getSocket());
+  }
+#endif // HAVE_LIBSSH2
+
+  return make_unique<FtpNegotiationCommand>(getCuid(), getRequest(),
+                                            getFileEntry(), getRequestGroup(),
+                                            getDownloadEngine(), getSocket());
 }
 
 } // namespace aria2
