@@ -75,12 +75,10 @@
 #include "SocketRecvBuffer.h"
 #include "MetalinkHttpEntry.h"
 #include "NullProgressInfoFile.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "Checksum.h"
-# include "ChecksumCheckIntegrityEntry.h"
-#endif // ENABLE_MESSAGE_DIGEST
+#include "Checksum.h"
+#include "ChecksumCheckIntegrityEntry.h"
 #ifdef HAVE_ZLIB
-# include "GZipDecodingStreamFilter.h"
+#include "GZipDecodingStreamFilter.h"
 #endif // HAVE_ZLIB
 
 namespace aria2 {
@@ -105,9 +103,9 @@ std::unique_ptr<StreamFilter> getTransferEncodingStreamFilter(
   return delegate;
 }
 
-std::unique_ptr<StreamFilter> getContentEncodingStreamFilter(
-    HttpResponse* httpResponse,
-    std::unique_ptr<StreamFilter> delegate = nullptr)
+std::unique_ptr<StreamFilter>
+getContentEncodingStreamFilter(HttpResponse* httpResponse,
+                               std::unique_ptr<StreamFilter> delegate = nullptr)
 {
   if (httpResponse->isContentEncodingSpecified()) {
     auto filter = httpResponse->getContentEncodingStreamFilter();
@@ -118,9 +116,11 @@ std::unique_ptr<StreamFilter> getContentEncodingStreamFilter(
                       "still encoded.",
                       httpResponse->getContentEncoding().c_str()));
     }
-    filter->init();
-    filter->installDelegate(std::move(delegate));
-    return filter;
+    else {
+      filter->init();
+      filter->installDelegate(std::move(delegate));
+      return filter;
+    }
   }
   return delegate;
 }
@@ -128,17 +128,13 @@ std::unique_ptr<StreamFilter> getContentEncodingStreamFilter(
 } // namespace
 
 HttpResponseCommand::HttpResponseCommand(
-    cuid_t cuid,
-    const std::shared_ptr<Request>& req,
-    const std::shared_ptr<FileEntry>& fileEntry,
-    RequestGroup* requestGroup,
-    const std::shared_ptr<HttpConnection>& httpConnection,
-    DownloadEngine* e,
+    cuid_t cuid, const std::shared_ptr<Request>& req,
+    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
+    const std::shared_ptr<HttpConnection>& httpConnection, DownloadEngine* e,
     const std::shared_ptr<SocketCore>& s)
-  :
-    AbstractCommand(cuid, req, fileEntry, requestGroup, e, s,
-                    httpConnection->getSocketRecvBuffer()),
-    httpConnection_(httpConnection)
+    : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s,
+                      httpConnection->getSocketRecvBuffer()),
+      httpConnection_(httpConnection)
 {
   checkSocketRecvBuffer();
 }
@@ -203,18 +199,17 @@ bool HttpResponseCommand::executeInternal()
         ctx->setAcceptMetalink(false);
         std::vector<MetalinkHttpEntry> entries;
         httpResponse->getMetalinKHttpEntries(entries, getOption());
-        for(const auto& e : entries) {
+        for (const auto& e : entries) {
           fe->addUri(e.uri);
           A2_LOG_DEBUG(fmt("Adding URI=%s", e.uri.c_str()));
         }
       }
     }
 
-#ifdef ENABLE_MESSAGE_DIGEST
     if (httpHeader->defined(HttpHeader::DIGEST)) {
       std::vector<Checksum> checksums;
       httpResponse->getDigest(checksums);
-      for(const auto &checksum : checksums) {
+      for (const auto& checksum : checksums) {
         if (ctx->getHashType().empty()) {
           A2_LOG_DEBUG(fmt("Setting digest: type=%s, digest=%s",
                            checksum.getHashType().c_str(),
@@ -228,11 +223,10 @@ bool HttpResponseCommand::executeInternal()
         }
       }
     }
-#endif // ENABLE_MESSAGE_DIGEST
   }
 
-  if(statusCode >= 300) {
-    if(statusCode == 404) {
+  if (statusCode >= 300) {
+    if (statusCode == 404) {
       grp->increaseAndValidateFileNotFoundCount();
     }
     return skipResponseBody(std::move(httpResponse));
@@ -254,8 +248,10 @@ bool HttpResponseCommand::executeInternal()
     int64_t totalLength = httpResponse->getEntityLength();
     fe->setLength(totalLength);
     if (fe->getPath().empty()) {
-      fe->setPath(util::createSafePath(getOption()->get(PREF_DIR),
-                                       httpResponse->determineFilename()));
+      auto suffixPath = util::createSafePath(httpResponse->determineFilename());
+
+      fe->setPath(util::applyDir(getOption()->get(PREF_DIR), suffixPath));
+      fe->setSuffixPath(suffixPath);
     }
     fe->setContentType(httpResponse->getContentType());
     grp->preDownloadProcessing();
@@ -264,12 +260,15 @@ bool HttpResponseCommand::executeInternal()
     updateLastModifiedTime(httpResponse->getLastModifiedTime());
 
     // If both transfer-encoding and total length is specified, we
-    // assume we can do segmented downloading
+    // should have ignored total length.  In this case, we can not do
+    // segmented downloading
     if (totalLength == 0 || shouldInflateContentEncoding(httpResponse.get())) {
       // we ignore content-length when inflate is required
       fe->setLength(0);
-      if (req->getMethod() == Request::METHOD_GET && (totalLength != 0 ||
-            !httpResponse->getHttpHeader()->defined(HttpHeader::CONTENT_LENGTH))){
+      if (req->getMethod() == Request::METHOD_GET &&
+          (totalLength != 0 ||
+           !httpResponse->getHttpHeader()->defined(
+               HttpHeader::CONTENT_LENGTH))) {
         // DownloadContext::knowsTotalLength() == true only when
         // server says the size of file is 0 explicitly.
         getDownloadContext()->markTotalLengthIsUnknown();
@@ -280,17 +279,15 @@ bool HttpResponseCommand::executeInternal()
     return handleDefaultEncoding(std::move(httpResponse));
   }
 
-#ifdef ENABLE_MESSAGE_DIGEST
   if (!ctx->getHashType().empty() && httpHeader->defined(HttpHeader::DIGEST)) {
     std::vector<Checksum> checksums;
     httpResponse->getDigest(checksums);
-    for (const auto &checksum : checksums) {
+    for (const auto& checksum : checksums) {
       if (checkChecksum(ctx, checksum)) {
         break;
       }
     }
   }
-#endif // ENABLE_MESSAGE_DIGEST
 
   // validate totalsize
   grp->validateTotalLength(fe->getLength(), httpResponse->getEntityLength());
@@ -304,17 +301,14 @@ bool HttpResponseCommand::executeInternal()
     // anyway.
     getPieceStorage()->getDiskAdaptor()->truncate(0);
     auto teFilter = getTransferEncodingStreamFilter(
-        httpResponse.get(),
-        getContentEncodingStreamFilter(httpResponse.get()));
-    getDownloadEngine()->addCommand(
-        createHttpDownloadCommand(std::move(httpResponse),
-                                  std::move(teFilter)));
+        httpResponse.get(), getContentEncodingStreamFilter(httpResponse.get()));
+    getDownloadEngine()->addCommand(createHttpDownloadCommand(
+        std::move(httpResponse), std::move(teFilter)));
   }
   else {
     auto teFilter = getTransferEncodingStreamFilter(httpResponse.get());
-    getDownloadEngine()->addCommand(
-        createHttpDownloadCommand(std::move(httpResponse),
-                                  std::move(teFilter)));
+    getDownloadEngine()->addCommand(createHttpDownloadCommand(
+        std::move(httpResponse), std::move(teFilter)));
   }
 
   return true;
@@ -339,7 +333,7 @@ bool HttpResponseCommand::shouldInflateContentEncoding(
   // implementation just inflates these files nonetheless.
   const std::string& ce = httpResponse->getContentEncoding();
   return httpResponse->getHttpRequest()->acceptGZip() &&
-    (ce == "gzip" || ce == "deflate");
+         (ce == "gzip" || ce == "deflate");
 }
 
 bool HttpResponseCommand::handleDefaultEncoding(
@@ -350,7 +344,7 @@ bool HttpResponseCommand::handleDefaultEncoding(
   getRequestGroup()->adjustFilename(progressInfoFile);
   getRequestGroup()->initPieceStorage();
 
-  if(getOption()->getAsBool(PREF_DRY_RUN)) {
+  if (getOption()->getAsBool(PREF_DRY_RUN)) {
     onDryRunFileFound();
     return true;
   }
@@ -366,17 +360,16 @@ bool HttpResponseCommand::handleDefaultEncoding(
   // AbstractCommand::execute()
   auto segment = getSegmentMan()->getSegmentWithIndex(getCuid(), 0);
   // pipelining requires implicit range specified. But the request for
-  // this response most likely dones't contains range header. This means
+  // this response most likely doesn't contains range header. This means
   // we can't continue to use this socket because server sends all entity
   // body instead of a segment.
   // Therefore, we shutdown the socket here if pipelining is enabled.
-  if (getRequest()->getMethod() == Request::METHOD_GET &&
-     segment && segment->getPositionToWrite() == 0 &&
-     !getRequest()->isPipeliningEnabled()) {
+  if (getRequest()->getMethod() == Request::METHOD_GET && segment &&
+      segment->getPositionToWrite() == 0 &&
+      !getRequest()->isPipeliningEnabled()) {
     auto teFilter = getTransferEncodingStreamFilter(httpResponse.get());
-    checkEntry->pushNextCommand(
-        createHttpDownloadCommand(std::move(httpResponse),
-                                  std::move(teFilter)));
+    checkEntry->pushNextCommand(createHttpDownloadCommand(
+        std::move(httpResponse), std::move(teFilter)));
   }
   else {
     getSegmentMan()->cancelSegment(getCuid());
@@ -416,27 +409,26 @@ bool HttpResponseCommand::handleOtherEncoding(
       httpResponse.get(), getContentEncodingStreamFilter(httpResponse.get()));
   // If chunked transfer-encoding is specified, we have to read end of
   // chunk markers(0\r\n\r\n, for example).
-  bool chunkedUsed = streamFilter &&
-    streamFilter->getName() == ChunkedDecodingStreamFilter::NAME;
+  bool chunkedUsed =
+      streamFilter &&
+      streamFilter->getName() == ChunkedDecodingStreamFilter::NAME;
 
   // For zero-length file, check existing file comparing its size
   if (!chunkedUsed && getDownloadContext()->knowsTotalLength() &&
       getRequestGroup()->downloadFinishedByFileLength()) {
     getRequestGroup()->initPieceStorage();
 
-#ifdef ENABLE_MESSAGE_DIGEST
     // TODO Known issue: if .aria2 file exists, it will not be deleted
     // on successful verification, because .aria2 file is not loaded.
     // See also FtpNegotiationCommand::onFileSizeDetermined()
-    if(getDownloadContext()->isChecksumVerificationNeeded()) {
+    if (getDownloadContext()->isChecksumVerificationNeeded()) {
       A2_LOG_DEBUG("Zero length file exists. Verify checksum.");
       auto entry = make_unique<ChecksumCheckIntegrityEntry>(getRequestGroup());
       entry->initValidator();
       getPieceStorage()->getDiskAdaptor()->openExistingFile();
       getDownloadEngine()->getCheckIntegrityMan()->pushEntry(std::move(entry));
-    } else
-#endif // ENABLE_MESSAGE_DIGEST
-    {
+    }
+    else {
       getPieceStorage()->markAllPiecesDone();
       getDownloadContext()->setChecksumVerified(true);
       A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
@@ -459,15 +451,13 @@ bool HttpResponseCommand::handleOtherEncoding(
     // TODO Known issue: if .aria2 file exists, it will not be deleted
     // on successful verification, because .aria2 file is not loaded.
     // See also FtpNegotiationCommand::onFileSizeDetermined()
-#ifdef ENABLE_MESSAGE_DIGEST
     if (getDownloadContext()->isChecksumVerificationNeeded()) {
       A2_LOG_DEBUG("Verify checksum for zero-length file");
       auto entry = make_unique<ChecksumCheckIntegrityEntry>(getRequestGroup());
       entry->initValidator();
       getDownloadEngine()->getCheckIntegrityMan()->pushEntry(std::move(entry));
-    } else
-#endif // ENABLE_MESSAGE_DIGEST
-    {
+    }
+    else {
       getRequestGroup()->getPieceStorage()->markAllPiecesDone();
     }
     poolConnection();
@@ -479,9 +469,8 @@ bool HttpResponseCommand::handleOtherEncoding(
   // AbstractCommand::execute()
   getSegmentMan()->getSegmentWithIndex(getCuid(), 0);
 
-  getDownloadEngine()->addCommand(
-      createHttpDownloadCommand(std::move(httpResponse),
-                                std::move(streamFilter)));
+  getDownloadEngine()->addCommand(createHttpDownloadCommand(
+      std::move(httpResponse), std::move(streamFilter)));
   return true;
 }
 
@@ -518,7 +507,7 @@ namespace {
 bool decideFileAllocation(StreamFilter* filter)
 {
 #ifdef HAVE_ZLIB
-  for (StreamFilter* f = filter; f; f = f->getDelegate().get()){
+  for (StreamFilter* f = filter; f; f = f->getDelegate().get()) {
     // Since the compressed file's length are returned in the response header
     // and the decompressed file size is unknown at this point, disable file
     // allocation here.
@@ -543,7 +532,8 @@ HttpResponseCommand::createHttpDownloadCommand(
       getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
       std::move(httpResponse), httpConnection_, getDownloadEngine(),
       getSocket());
-  command->setStartupIdleTime(getOption()->getAsInt(PREF_STARTUP_IDLE_TIME));
+  command->setStartupIdleTime(
+      std::chrono::seconds(getOption()->getAsInt(PREF_STARTUP_IDLE_TIME)));
   command->setLowestDownloadSpeedLimit(
       getOption()->getAsInt(PREF_LOWEST_SPEED_LIMIT));
   if (getRequestGroup()->isFileAllocationEnabled() &&
@@ -572,7 +562,6 @@ void HttpResponseCommand::onDryRunFileFound()
   poolConnection();
 }
 
-#ifdef ENABLE_MESSAGE_DIGEST
 bool HttpResponseCommand::checkChecksum(
     const std::shared_ptr<DownloadContext>& dctx, const Checksum& checksum)
 {
@@ -586,6 +575,5 @@ bool HttpResponseCommand::checkChecksum(
 
   return false;
 }
-#endif // ENABLE_MESSAGE_DIGEST
 
 } // namespace aria2
