@@ -41,17 +41,16 @@
 #include <sys/event.h>
 #include <sys/time.h>
 
-#include <deque>
+#include <map>
 
 #include "Event.h"
+#include "a2functional.h"
 #ifdef ENABLE_ASYNC_DNS
-# include "AsyncNameResolver.h"
+#include "AsyncNameResolver.h"
 #endif // ENABLE_ASYNC_DNS
 
 namespace aria2 {
 
-class Logger;
-
 class KqueueEventPoll : public EventPoll {
 private:
   class KSocketEntry;
@@ -63,11 +62,13 @@ private:
   typedef AsyncNameResolverEntry<KqueueEventPoll> KAsyncNameResolverEntry;
   friend class AsyncNameResolverEntry<KqueueEventPoll>;
 
-  class KSocketEntry:
-    public SocketEntry<KCommandEvent, KADNSEvent> {
+  class KSocketEntry : public SocketEntry<KCommandEvent, KADNSEvent> {
   public:
     KSocketEntry(sock_t socket);
 
+    KSocketEntry(const KSocketEntry&) = delete;
+    KSocketEntry(KSocketEntry&&) = default;
+
     // eventlist should be at least size 2.  This function returns the
     // number of filled struct kevent in eventlist.
     size_t getEvents(struct kevent* eventlist);
@@ -76,30 +77,31 @@ private:
   friend int accumulateEvent(int events, const KEvent& event);
 
 private:
-  std::deque<SharedHandle<KSocketEntry> > socketEntries_;
+  typedef std::map<sock_t, KSocketEntry> KSocketEntrySet;
+  KSocketEntrySet socketEntries_;
 #ifdef ENABLE_ASYNC_DNS
-  std::deque<SharedHandle<KAsyncNameResolverEntry> > nameResolverEntries_;
+  typedef std::map<std::pair<AsyncNameResolver*, Command*>,
+                   KAsyncNameResolverEntry> KAsyncNameResolverEntrySet;
+  KAsyncNameResolverEntrySet nameResolverEntries_;
 #endif // ENABLE_ASYNC_DNS
 
   int kqfd_;
 
   size_t kqEventsSize_;
 
-  struct kevent* kqEvents_;
+  std::unique_ptr<struct kevent[]> kqEvents_;
 
   static const size_t KQUEUE_EVENTS_MAX = 1024;
 
-  Logger* logger_;
-
   bool addEvents(sock_t socket, const KEvent& event);
 
   bool deleteEvents(sock_t socket, const KEvent& event);
 
   bool addEvents(sock_t socket, Command* command, int events,
-                 const SharedHandle<AsyncNameResolver>& rs);
+                 const std::shared_ptr<AsyncNameResolver>& rs);
 
   bool deleteEvents(sock_t socket, Command* command,
-                    const SharedHandle<AsyncNameResolver>& rs);
+                    const std::shared_ptr<AsyncNameResolver>& rs);
 
 public:
   KqueueEventPoll();
@@ -108,19 +110,21 @@ public:
 
   virtual ~KqueueEventPoll();
 
-  virtual void poll(const struct timeval& tv);
+  virtual void poll(const struct timeval& tv) CXX11_OVERRIDE;
 
-  virtual bool addEvents(sock_t socket,
-                         Command* command, EventPoll::EventType events);
+  virtual bool addEvents(sock_t socket, Command* command,
+                         EventPoll::EventType events) CXX11_OVERRIDE;
 
-  virtual bool deleteEvents(sock_t socket,
-                            Command* command, EventPoll::EventType events);
+  virtual bool deleteEvents(sock_t socket, Command* command,
+                            EventPoll::EventType events) CXX11_OVERRIDE;
 #ifdef ENABLE_ASYNC_DNS
 
-  virtual bool addNameResolver(const SharedHandle<AsyncNameResolver>& resolver,
-                               Command* command);
-  virtual bool deleteNameResolver
-  (const SharedHandle<AsyncNameResolver>& resolver, Command* command);
+  virtual bool
+  addNameResolver(const std::shared_ptr<AsyncNameResolver>& resolver,
+                  Command* command) CXX11_OVERRIDE;
+  virtual bool
+  deleteNameResolver(const std::shared_ptr<AsyncNameResolver>& resolver,
+                     Command* command) CXX11_OVERRIDE;
 #endif // ENABLE_ASYNC_DNS
 
   static const int IEV_READ = POLLIN;
