@@ -36,8 +36,8 @@
 #include "common.h"
 
 #include <string>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "TimerA2.h"
 
 namespace aria2 {
@@ -46,24 +46,25 @@ class SocketCore;
 
 class LpdMessageDispatcher {
 private:
-  SharedHandle<SocketCore> socket_;
+  std::shared_ptr<SocketCore> socket_;
   std::string infoHash_;
   uint16_t port_;
   std::string multicastAddress_;
   uint16_t multicastPort_;
   Timer timer_;
-  time_t interval_;
+  std::chrono::seconds interval_;
   std::string request_;
+
 public:
-  LpdMessageDispatcher
-  (const std::string& infoHash, uint16_t port,
-   const std::string& multicastAddr, uint16_t multicastPort,
-   time_t interval = 5*60);
+  LpdMessageDispatcher(const std::string& infoHash, uint16_t port,
+                       const std::string& multicastAddr, uint16_t multicastPort,
+                       std::chrono::seconds interval = 5_min);
 
   ~LpdMessageDispatcher();
 
   // No throw
-  bool init(const std::string& localAddr, unsigned char ttl,unsigned char loop);
+  bool init(const std::string& localAddr, unsigned char ttl,
+            unsigned char loop);
 
   // Returns true if timer_ reached announce interval, which is by
   // default 5mins.
@@ -76,22 +77,16 @@ public:
   // Reset timer_ to the current time.
   void resetAnnounceTimer();
 
-  const std::string& getInfoHash() const
-  {
-    return infoHash_;
-  }
+  const std::string& getInfoHash() const { return infoHash_; }
 
-  uint16_t getPort() const
-  {
-    return port_;
-  }
+  uint16_t getPort() const { return port_; }
 };
 
 namespace bittorrent {
 
-std::string createLpdRequest
-(const std::string& multicastAddress, uint16_t multicastPort,
- const std::string& infoHash, uint16_t port);
+std::string createLpdRequest(const std::string& multicastAddress,
+                             uint16_t multicastPort,
+                             const std::string& infoHash, uint16_t port);
 
 } // namespace bittorrent
 
