@@ -16,7 +16,7 @@
 
 namespace aria2 {
 
-class MultiDiskAdaptorTest:public CppUnit::TestFixture {
+class MultiDiskAdaptorTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(MultiDiskAdaptorTest);
   CPPUNIT_TEST(testWriteData);
@@ -27,11 +27,14 @@ class MultiDiskAdaptorTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testResetDiskWriterEntries);
   CPPUNIT_TEST(testWriteCache);
   CPPUNIT_TEST_SUITE_END();
+
 private:
-  SharedHandle<MultiDiskAdaptor> adaptor;
+  std::unique_ptr<MultiDiskAdaptor> adaptor;
+
 public:
-  void setUp() {
-    adaptor.reset(new MultiDiskAdaptor());
+  void setUp()
+  {
+    adaptor = make_unique<MultiDiskAdaptor>();
     adaptor->setPieceLength(2);
   }
 
@@ -44,20 +47,20 @@ public:
   void testWriteCache();
 };
 
+CPPUNIT_TEST_SUITE_REGISTRATION(MultiDiskAdaptorTest);
 
-CPPUNIT_TEST_SUITE_REGISTRATION( MultiDiskAdaptorTest );
-
-std::vector<SharedHandle<FileEntry> > createEntries() {
-  SharedHandle<FileEntry> array[] = {
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file0.txt", 0, 0)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file1.txt", 15, 0)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file2.txt", 7, 15)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file3.txt", 0, 22)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file4.txt", 2, 22)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file5.txt", 0, 24)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file6.txt", 3, 24)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file7.txt", 0, 27)),
-    SharedHandle<FileEntry>(new FileEntry(A2_TEST_OUT_DIR"/file8.txt", 2, 27)),
+std::vector<std::shared_ptr<FileEntry>> createEntries()
+{
+  std::vector<std::shared_ptr<FileEntry>> entries{
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file0.txt", 0, 0),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file1.txt", 15, 0),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file2.txt", 7, 15),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file3.txt", 0, 22),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file4.txt", 2, 22),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file5.txt", 0, 24),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file6.txt", 3, 24),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file7.txt", 0, 27),
+      std::make_shared<FileEntry>(A2_TEST_OUT_DIR "/file8.txt", 2, 27),
   };
   //           1    1    2    2    3
   // 0....5....0....5....0....5....0
@@ -71,10 +74,8 @@ std::vector<SharedHandle<FileEntry> > createEntries() {
   //                         *** file6
   //                            |file7
   //                            ** file8
-  std::vector<SharedHandle<FileEntry> > entries(vbegin(array), vend(array));
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator i = entries.begin();
-      i != entries.end(); ++i) {
-    File((*i)->getPath()).remove();
+  for (const auto& i : entries) {
+    File(i->getPath()).remove();
   }
   return entries;
 }
@@ -82,13 +83,12 @@ std::vector<SharedHandle<FileEntry> > createEntries() {
 void MultiDiskAdaptorTest::testResetDiskWriterEntries()
 {
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(entries[2]->getDiskWriter());
@@ -99,14 +99,13 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     fileEntries[0]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     // Because entries[1] spans entries[0]
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
@@ -118,15 +117,14 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     fileEntries[0]->setRequested(false);
     fileEntries[1]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(!entries[0]->getDiskWriter());
     // Because entries[2] spans entries[1]
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
@@ -139,14 +137,13 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     fileEntries[3]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(entries[2]->getDiskWriter());
@@ -159,14 +156,13 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     fileEntries[4]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(entries[2]->getDiskWriter());
@@ -178,15 +174,14 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
+    auto fileEntries = createEntries();
     fileEntries[3]->setRequested(false);
     fileEntries[4]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(entries[2]->getDiskWriter());
@@ -197,16 +192,15 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
-    for(size_t i = 5; i < 9; ++i) {
+    auto fileEntries = createEntries();
+    for (size_t i = 5; i < 9; ++i) {
       fileEntries[i]->setRequested(false);
     }
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     // In openFile(), resetDiskWriterEntries() are called.
     adaptor->openFile();
 
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(entries[2]->getDiskWriter());
@@ -217,14 +211,13 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
-    for(size_t i = 1; i < 9; ++i) {
+    auto fileEntries = createEntries();
+    for (size_t i = 1; i < 9; ++i) {
       fileEntries[i]->setRequested(false);
     }
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     adaptor->openFile();
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(!entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(!entries[2]->getDiskWriter());
@@ -235,14 +228,13 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
-    for(size_t i = 2; i < 9; ++i) {
+    auto fileEntries = createEntries();
+    for (size_t i = 2; i < 9; ++i) {
       fileEntries[i]->setRequested(false);
     }
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     adaptor->openFile();
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(entries[1]->getDiskWriter());
     // entries[1] spans entries[2]
@@ -255,15 +247,14 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
     adaptor->closeFile();
   }
   {
-    std::vector<SharedHandle<FileEntry> > fileEntries = createEntries();
-    for(size_t i = 0; i < 6; ++i) {
+    auto fileEntries = createEntries();
+    for (size_t i = 0; i < 6; ++i) {
       fileEntries[i]->setRequested(false);
     }
     fileEntries[8]->setRequested(false);
     adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
     adaptor->openFile();
-    std::vector<SharedHandle<DiskWriterEntry> > entries =
-      adaptor->getDiskWriterEntries();
+    auto& entries = adaptor->getDiskWriterEntries();
     CPPUNIT_ASSERT(!entries[0]->getDiskWriter());
     CPPUNIT_ASSERT(!entries[1]->getDiskWriter());
     CPPUNIT_ASSERT(!entries[2]->getDiskWriter());
@@ -279,30 +270,32 @@ void MultiDiskAdaptorTest::testResetDiskWriterEntries()
   }
 }
 
-void readFile(const std::string& filename, char* buf, int bufLength) {
+void readFile(const std::string& filename, char* buf, int bufLength)
+{
   FILE* f = fopen(filename.c_str(), "r");
-  if(f == NULL) {
+  if (f == nullptr) {
     CPPUNIT_FAIL(strerror(errno));
   }
   int retval = fread(buf, bufLength, 1, f);
   fclose(f);
-  if(retval != 1) {
+  if (retval != 1) {
     CPPUNIT_FAIL("return value is not 1");
   }
 }
 
-void MultiDiskAdaptorTest::testWriteData() {
-  std::vector<SharedHandle<FileEntry> > fileEntries(createEntries());
-  adaptor->setFileEntries(fileEntries.begin(), fileEntries.end());
+void MultiDiskAdaptorTest::testWriteData()
+{
+  auto fileEntries = createEntries();
+  adaptor->setFileEntries(std::begin(fileEntries), std::end(fileEntries));
 
   adaptor->openFile();
   std::string msg = "12345";
   adaptor->writeData((const unsigned char*)msg.c_str(), msg.size(), 0);
   adaptor->closeFile();
 
-  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR"/file0.txt").isFile());
+  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR "/file0.txt").isFile());
   char buf[128];
-  readFile(A2_TEST_OUT_DIR"/file1.txt", buf, 5);
+  readFile(A2_TEST_OUT_DIR "/file1.txt", buf, 5);
   buf[5] = '\0';
   CPPUNIT_ASSERT_EQUAL(msg, std::string(buf));
 
@@ -311,10 +304,10 @@ void MultiDiskAdaptorTest::testWriteData() {
   adaptor->writeData((const unsigned char*)msg2.c_str(), msg2.size(), 5);
   adaptor->closeFile();
 
-  readFile(A2_TEST_OUT_DIR"/file1.txt", buf, 15);
+  readFile(A2_TEST_OUT_DIR "/file1.txt", buf, 15);
   buf[15] = '\0';
   CPPUNIT_ASSERT_EQUAL(std::string("1234567890ABCDE"), std::string(buf));
-  readFile(A2_TEST_OUT_DIR"/file2.txt", buf, 1);
+  readFile(A2_TEST_OUT_DIR "/file2.txt", buf, 1);
   buf[1] = '\0';
   CPPUNIT_ASSERT_EQUAL(std::string("F"), std::string(buf));
 
@@ -323,32 +316,30 @@ void MultiDiskAdaptorTest::testWriteData() {
   adaptor->writeData((const unsigned char*)msg3.c_str(), msg3.size(), 10);
   adaptor->closeFile();
 
-  readFile(A2_TEST_OUT_DIR"/file1.txt", buf, 15);
+  readFile(A2_TEST_OUT_DIR "/file1.txt", buf, 15);
   buf[15] = '\0';
   CPPUNIT_ASSERT_EQUAL(std::string("123456789012345"), std::string(buf));
-  readFile(A2_TEST_OUT_DIR"/file2.txt", buf, 7);
+  readFile(A2_TEST_OUT_DIR "/file2.txt", buf, 7);
   buf[7] = '\0';
   CPPUNIT_ASSERT_EQUAL(std::string("1234567"), std::string(buf));
 
-  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR"/file3.txt").isFile());
+  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR "/file3.txt").isFile());
 
-  readFile(A2_TEST_OUT_DIR"/file4.txt", buf, 2);
+  readFile(A2_TEST_OUT_DIR "/file4.txt", buf, 2);
   buf[2] = '\0';
   CPPUNIT_ASSERT_EQUAL(std::string("12"), std::string(buf));
 
-  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR"/file5.txt").isFile());
+  CPPUNIT_ASSERT(File(A2_TEST_OUT_DIR "/file5.txt").isFile());
 }
 
-void MultiDiskAdaptorTest::testReadData() {
-  SharedHandle<FileEntry> entry1(new FileEntry(A2_TEST_DIR"/file1r.txt", 15, 0));
-  SharedHandle<FileEntry> entry2(new FileEntry(A2_TEST_DIR"/file2r.txt", 7, 15));
-  SharedHandle<FileEntry> entry3(new FileEntry(A2_TEST_DIR"/file3r.txt", 3, 22));
-  std::vector<SharedHandle<FileEntry> > entries;
-  entries.push_back(entry1);
-  entries.push_back(entry2);
-  entries.push_back(entry3);
+void MultiDiskAdaptorTest::testReadData()
+{
+  auto entries = std::vector<std::shared_ptr<FileEntry>>{
+      std::make_shared<FileEntry>(A2_TEST_DIR "/file1r.txt", 15, 0),
+      std::make_shared<FileEntry>(A2_TEST_DIR "/file2r.txt", 7, 15),
+      std::make_shared<FileEntry>(A2_TEST_DIR "/file3r.txt", 3, 22)};
 
-  adaptor->setFileEntries(entries.begin(), entries.end());
+  adaptor->setFileEntries(std::begin(entries), std::end(entries));
   adaptor->enableReadOnly();
   adaptor->openFile();
   unsigned char buf[128];
@@ -363,55 +354,46 @@ void MultiDiskAdaptorTest::testReadData() {
   CPPUNIT_ASSERT_EQUAL(std::string("KLMN"), std::string((char*)buf));
   adaptor->readData(buf, 25, 0);
   buf[25] = '\0';
-  CPPUNIT_ASSERT_EQUAL(std::string("1234567890ABCDEFGHIJKLMNO"), std::string((char*)buf));
+  CPPUNIT_ASSERT_EQUAL(std::string("1234567890ABCDEFGHIJKLMNO"),
+                       std::string((char*)buf));
 }
 
 void MultiDiskAdaptorTest::testCutTrailingGarbage()
 {
   std::string dir = A2_TEST_OUT_DIR;
   std::string prefix = "aria2_MultiDiskAdaptorTest_testCutTrailingGarbage_";
-  SharedHandle<FileEntry> entries[] = {
-    SharedHandle<FileEntry>(new FileEntry(dir+"/"+prefix+"1", 256, 0)),
-    SharedHandle<FileEntry>(new FileEntry(dir+"/"+prefix+"2", 512, 256))
-  };
-  for(size_t i = 0; i < A2_ARRAY_LEN(entries); ++i) {
-    createFile(entries[i]->getPath(), entries[i]->getLength()+100);
+  auto fileEntries = std::vector<std::shared_ptr<FileEntry>>{
+      std::make_shared<FileEntry>(dir + "/" + prefix + "1", 256, 0),
+      std::make_shared<FileEntry>(dir + "/" + prefix + "2", 512, 256)};
+  for (const auto& i : fileEntries) {
+    createFile(i->getPath(), i->getLength() + 100);
   }
-  std::vector<SharedHandle<FileEntry> > fileEntries
-    (vbegin(entries), vend(entries));
 
   MultiDiskAdaptor adaptor;
-  adaptor.setFileEntries(fileEntries.begin(), fileEntries.end());
-  adaptor.setMaxOpenFiles(1);
+  adaptor.setFileEntries(std::begin(fileEntries), std::end(fileEntries));
   adaptor.setPieceLength(1);
 
   adaptor.openFile();
 
   adaptor.cutTrailingGarbage();
 
-  CPPUNIT_ASSERT_EQUAL((int64_t)256,
-                       File(entries[0]->getPath()).size());
-  CPPUNIT_ASSERT_EQUAL((int64_t)512,
-                       File(entries[1]->getPath()).size());
+  CPPUNIT_ASSERT_EQUAL((int64_t)256, File(fileEntries[0]->getPath()).size());
+  CPPUNIT_ASSERT_EQUAL((int64_t)512, File(fileEntries[1]->getPath()).size());
 }
 
 void MultiDiskAdaptorTest::testSize()
 {
   std::string dir = A2_TEST_OUT_DIR;
   std::string prefix = "aria2_MultiDiskAdaptorTest_testSize_";
-  SharedHandle<FileEntry> entries[] = {
-    SharedHandle<FileEntry>(new FileEntry(dir+"/"+prefix+"1", 1, 0)),
-    SharedHandle<FileEntry>(new FileEntry(dir+"/"+prefix+"2", 1, 1))
-  };
-  for(size_t i = 0; i < A2_ARRAY_LEN(entries); ++i) {
-    createFile(entries[i]->getPath(), entries[i]->getLength());
+  auto fileEntries = std::vector<std::shared_ptr<FileEntry>>{
+      std::make_shared<FileEntry>(dir + "/" + prefix + "1", 1, 0),
+      std::make_shared<FileEntry>(dir + "/" + prefix + "2", 1, 1)};
+  for (const auto& i : fileEntries) {
+    createFile(i->getPath(), i->getLength());
   }
-  std::vector<SharedHandle<FileEntry> > fileEntries
-    (vbegin(entries), vend(entries));
 
   MultiDiskAdaptor adaptor;
-  adaptor.setFileEntries(fileEntries.begin(), fileEntries.end());
-  adaptor.setMaxOpenFiles(1);
+  adaptor.setFileEntries(std::begin(fileEntries), std::end(fileEntries));
   adaptor.setPieceLength(1);
 
   adaptor.openFile();
@@ -421,12 +403,13 @@ void MultiDiskAdaptorTest::testSize()
 
 void MultiDiskAdaptorTest::testUtime()
 {
-  std::string storeDir = A2_TEST_OUT_DIR"/aria2_MultiDiskAdaptorTest_testUtime";
-  SharedHandle<FileEntry> entries[] = {
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/requested", 0, 0)),
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/notFound", 0, 0)),
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/notRequested", 0, 0)),
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/anotherRequested", 0, 0)),
+  std::string storeDir =
+      A2_TEST_OUT_DIR "/aria2_MultiDiskAdaptorTest_testUtime";
+  auto entries = std::vector<std::shared_ptr<FileEntry>>{
+      std::make_shared<FileEntry>(storeDir + "/requested", 0, 0),
+      std::make_shared<FileEntry>(storeDir + "/notFound", 0, 0),
+      std::make_shared<FileEntry>(storeDir + "/notRequested", 0, 0),
+      std::make_shared<FileEntry>(storeDir + "/anotherRequested", 0, 0),
   };
 
   createFile(entries[0]->getPath(), entries[0]->getLength());
@@ -436,64 +419,64 @@ void MultiDiskAdaptorTest::testUtime()
 
   entries[2]->setRequested(false);
 
-  std::vector<SharedHandle<FileEntry> > fileEntries
-    (vbegin(entries), vend(entries));
   MultiDiskAdaptor adaptor;
-  adaptor.setFileEntries(fileEntries.begin(), fileEntries.end());
+  adaptor.setFileEntries(std::begin(entries), std::end(entries));
 
-  time_t atime = (time_t) 100000;
-  time_t mtime = (time_t) 200000;
+  time_t atime = (time_t)100000;
+  time_t mtime = (time_t)200000;
 
   CPPUNIT_ASSERT_EQUAL((size_t)2, adaptor.utime(Time(atime), Time(mtime)));
 
-  CPPUNIT_ASSERT_EQUAL((time_t)mtime,
-                       File(entries[0]->getPath()).getModifiedTime().getTime());
+  CPPUNIT_ASSERT_EQUAL(
+      (time_t)mtime,
+      File(entries[0]->getPath()).getModifiedTime().getTimeFromEpoch());
 
-  CPPUNIT_ASSERT_EQUAL((time_t)mtime,
-                       File(entries[3]->getPath()).getModifiedTime().getTime());
+  CPPUNIT_ASSERT_EQUAL(
+      (time_t)mtime,
+      File(entries[3]->getPath()).getModifiedTime().getTimeFromEpoch());
 
-  CPPUNIT_ASSERT((time_t)mtime !=
-                 File(entries[2]->getPath()).getModifiedTime().getTime());
+  CPPUNIT_ASSERT(
+      (time_t)mtime !=
+      File(entries[2]->getPath()).getModifiedTime().getTimeFromEpoch());
 }
 
 void MultiDiskAdaptorTest::testWriteCache()
 {
   std::string storeDir =
-    A2_TEST_OUT_DIR"/aria2_MultiDiskAdaptorTest_testWriteCache";
-  SharedHandle<FileEntry> entries[] = {
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/file1", 16385, 0)),
-    SharedHandle<FileEntry>(new FileEntry(storeDir+"/file2", 4098, 16385))
-  };
-  for(int i = 0; i < 2; ++i) {
-    File(entries[i]->getPath()).remove();
+      A2_TEST_OUT_DIR "/aria2_MultiDiskAdaptorTest_testWriteCache";
+  auto entries = std::vector<std::shared_ptr<FileEntry>>{
+      std::make_shared<FileEntry>(storeDir + "/file1", 16385, 0),
+      std::make_shared<FileEntry>(storeDir + "/file2", 4098, 16385)};
+  for (const auto& i : entries) {
+    File(i->getPath()).remove();
   }
-  SharedHandle<MultiDiskAdaptor> adaptor(new MultiDiskAdaptor());
-  adaptor->setFileEntries(vbegin(entries), vend(entries));
-  WrDiskCacheEntry cache(adaptor);
+  auto adaptor = std::make_shared<MultiDiskAdaptor>();
+  adaptor->setFileEntries(std::begin(entries), std::end(entries));
+  WrDiskCacheEntry cache{adaptor};
   std::string data1(16383, '1'), data2(100, '2'), data3(4000, '3');
   cache.cacheData(createDataCell(0, data1.c_str()));
   cache.cacheData(createDataCell(data1.size(), data2.c_str()));
-  cache.cacheData(createDataCell(data1.size()+data2.size(), data3.c_str()));
+  cache.cacheData(createDataCell(data1.size() + data2.size(), data3.c_str()));
   adaptor->openFile();
   adaptor->writeCache(&cache);
-  for(int i = 0; i < 2; ++i) {
+  for (int i = 0; i < 2; ++i) {
     CPPUNIT_ASSERT_EQUAL(entries[i]->getLength(),
                          File(entries[i]->getPath()).size());
   }
-  CPPUNIT_ASSERT_EQUAL(data1+data2.substr(0, 2),
+  CPPUNIT_ASSERT_EQUAL(data1 + data2.substr(0, 2),
                        readFile(entries[0]->getPath()));
-  CPPUNIT_ASSERT_EQUAL(data2.substr(2)+data3,
+  CPPUNIT_ASSERT_EQUAL(data2.substr(2) + data3,
                        readFile(entries[1]->getPath()));
 
   adaptor->closeFile();
-  for(int i = 0; i < 2; ++i) {
+  for (int i = 0; i < 2; ++i) {
     File(entries[i]->getPath()).remove();
   }
   cache.clear();
   cache.cacheData(createDataCell(123, data2.c_str()));
   adaptor->openFile();
   adaptor->writeCache(&cache);
-  CPPUNIT_ASSERT_EQUAL((int64_t)(123+data2.size()),
+  CPPUNIT_ASSERT_EQUAL((int64_t)(123 + data2.size()),
                        File(entries[0]->getPath()).size());
   CPPUNIT_ASSERT_EQUAL(data2, readFile(entries[0]->getPath()).substr(123));
 }
